@@ -241,18 +241,18 @@ def parameters(path, debug):
         # Patch contrastive learning parameters
         args['PCL_CNN_Architecture']='resnet50' # or resnet18
         args['PCL_N_Workers']=0 # Number of data loading workers 
-        args['PCL_Epochs']=200 # Number of total epoch to run
-        args['PCL_N_Crops_per_Image']=100 # Number of crops chosen per image
+        args['PCL_Epochs']=100 # Number of total epoch to run
+        args['PCL_N_Crops_per_Image']=200 # Number of crops chosen per image
         args['PCL_Patch_Size']=30 # Size of patches in pixels
         args['PCL_Stride']=0 # Size of stride between consecutive patches
         args['PCL_Alpha_L']=1.15 # size ratio between image crop and image patch
         args['PCL_Z_Score']= True # Whether to apply z score per channel/marker 
-        args['PCL_Batch_Size']= 6 # Number of images per iteration
+        args['PCL_Batch_Size']= 4 # Number of images per iteration
         args['PCL_Weight_Decay']= 1e-4 # Weight Decay
         args['PCL_Out_Dimensions']= 128 # Feature dimensions of patch
-        args['PCL_Learning_Rate']= 0.003 # Learning Rate
+        args['PCL_Learning_Rate']= 0.000001 # Learning Rate
         args['PCL_Temperature']= 0.07 # Softmax temperature         
-        args['PCL_eliminate_Black_Background'] = False
+        args['PCL_eliminate_Black_Background'] = True
         args['PCL_eliminate_White_Background'] = False       
         args['PCL_GPU_INDEX']= torch.device('cuda:0') # GPU where the training is carried out 
 
